@@ -15,7 +15,7 @@ visreg:::se.mlm(fit)
 visreg(fit, "Species")
 
 ## Rug
-par(mfrow=c(3,1), mar=c(5, 5, 0.5, 0.5))
+par(mfrow=c(3,1), mar=c(5, 5, 0.5, 0.5), oma=c(0,0,2,0))
 visreg(fit, "Petal.Width", rug=TRUE, jitter=TRUE)
 visreg(fit, "Petal.Width", rug=TRUE, jitter=TRUE, type="contrast")
 visreg(fit, "Species", rug=TRUE)
@@ -32,5 +32,6 @@ visreg(fit, "Petal.Width", by="Petal.Length")
 visreg2d(fit, "Petal.Width", "Petal.Length")
 
 visreg2d(fit, "Petal.Width", "Petal.Length", plot.type="persp")
-visreg2d(fit, "Petal.Width", "Petal.Length", plot.type="persp", type="contrast")
-#visreg2d(fit, "Petal.Width", "Petal.Length", plot.type="rgl")
+p <- visreg2d(fit, "Petal.Width", "Petal.Length", plot.type="gg")
+gridExtra::marrangeGrob(p, nrow=2, ncol=1, top='')
+visreg2d(fit, "Petal.Width", "Petal.Length", plot.type="rgl")
